from setuptools import setup, find_packages

setup(name='server_chat_pyqt_december',
      version='0.0.1',
      description='Server packet',
      packages=find_packages(),
      author_email='007mail.ru96@mail.ru',
      author='Magomedov Magomed',
      install_requeres=['PyQt5', 'sqlalchemy', 'pycruptodome', 'pycryptodomex']
      )
